import setuptools

with open("README.md", "r") as fh:

    long_description = fh.read()

setuptools.setup(

     name='gtGen',  

     version='1.2',

     scripts=['gtGen'] ,

     author="Aravind Krishnan.B",

     author_email="aravindk797@gmail.com",

     description="GT_Generator Application",

     long_description=long_description,

   long_description_content_type="text/markdown",

     url="",

     packages=setuptools.find_packages(),
	 install_requires=[
			  'python-Levenshtein',
			  'Pillow'
	      ],
     classifiers=[

         "Programming Language :: Python :: 3",
	     'Programming Language :: Python :: 3.4',
	     'Programming Language :: Python :: 3.5',
	     'Programming Language :: Python :: 3.6',
	     'Programming Language :: Python :: 3.7',
         "License :: OSI Approved :: MIT License",

         "Operating System :: OS Independent",

     ],

 )